SystemOrganization addCategory: #ConfigurationOfTilingWindowManager!

Object subclass: #ConfigurationOfTilingWindowManager
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfTilingWindowManager'!

!ConfigurationOfTilingWindowManager commentStamp: 'LaurentLaffont 4/18/2012 21:49' prior: 0!
Tiling Window Manager is a set of tools to organize windows on you Pharo desktop.

Load with: 
  ConfigurationOfTilingWindowManager load.
(or see class side, protocol loading for alternate ways).

Then:
  TWMBar open.
(or browse settings for Tiling Window Manager).


If you want a more customized setup, try:

(Smalltalk at:#TWMUITheme) beCurrent. 
TaskbarMorph  showTaskbar: false.
TasklistMorph keepOpen: true.
(Smalltalk at:#TWMBar) perform: #showTWMBar: with: true.!

!ConfigurationOfTilingWindowManager class methodsFor: 'private' stamp: 'GuillermoPolito 6/12/2011 17:13'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfTilingWindowManager class methodsFor: 'private' stamp: 'GuillermoPolito 6/12/2011 17:13'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfTilingWindowManager class methodsFor: 'metacello tool support' stamp: 'GuillermoPolito 6/12/2011 17:13'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfTilingWindowManager class methodsFor: 'metacello tool support' stamp: 'GuillermoPolito 6/12/2011 17:13'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfTilingWindowManager class methodsFor: 'loading' stamp: 'ZekeriyaKoc 4/12/2012 16:25'!
load
	"self load"
	^(self project version: #stable) load! !

!ConfigurationOfTilingWindowManager class methodsFor: 'loading' stamp: 'ZekeriyaKoc 4/12/2012 16:19'!
loadDevelopment
	"self loadDevelopment"
	^(self project version: #development) load! !

!ConfigurationOfTilingWindowManager class methodsFor: 'loading' stamp: 'ZekeriyaKoc 4/12/2012 16:25'!
loadDevelopmentWithoutKeyMapping
	"self loadDevelopmentWithoutKeyMapping"
	^(self project version: #development) load: 'core'! !

!ConfigurationOfTilingWindowManager class methodsFor: 'metacello tool support' stamp: 'GuillermoPolito 6/12/2011 17:13'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfTilingWindowManager class methodsFor: 'accessing' stamp: 'GuillermoPolito 6/12/2011 17:13'!
project

	^self new project! !

!ConfigurationOfTilingWindowManager methodsFor: 'baselines' stamp: 'LaurentLaffont 3/21/2013 20:51'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		spec repository: 'http://smalltalkhub.com/mc/LaurentLaffont/TilingWindowManager/main'.
		spec project: 'Keymapping' with: [
				spec
					className: 'ConfigurationOfKeymapping';
					file: 'ConfigurationOfKeymapping';
					repository: 'http://www.squeaksource.com/ShortWays' ].
		spec package: 'TWM'.
			
		spec group: 'default' with: #('ALL')
	]! !

!ConfigurationOfTilingWindowManager methodsFor: 'baselines' stamp: 'LaurentLaffont 3/21/2013 20:51'!
baseline13: spec 
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		spec project: 'Keymapping' with: [
				spec
					className: 'ConfigurationOfKeymapping';
					file: 'ConfigurationOfKeymapping';
					repository: 'http://www.squeaksource.com/ShortWays' ].
				
		spec 
			repository: 'http://smalltalkhub.com/mc/LaurentLaffont/TilingWindowManager/main';
			package: 'TWM-Core';
			package: 'TWM-GUI' with: [spec requires: 'TWM-Core'];
			package: 'TWM-KeyMapping' with: [spec requires: 'TWM-GUI'];
			package: 'TWM-Tests' with: [spec requires: #('TWM-GUI' 'TWM-KeyMapping')];
			package: 'TWM-Theme'.
			
		spec 
			group: 'default' with: #('ALL');
			group: 'core' with: #('TWM-GUI')
	]! !

!ConfigurationOfTilingWindowManager methodsFor: 'baselines' stamp: 'LaurentLaffont 3/21/2013 20:55'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		spec 
			repository: 'http://smalltalkhub.com/mc/LaurentLaffont/TilingWindowManager/main';
			package: 'TWM-Core';
			package: 'TWM-GUI' with: [spec requires: 'TWM-Core'];
			package: 'TWM-KeyMapping' with: [spec requires: 'TWM-GUI'];
			package: 'TWM-Tests' with: [spec requires: #('TWM-GUI' 'TWM-KeyMapping')];
			package: 'TWM-Theme'.
			
		spec 
			group: 'default' with: #('ALL');
			group: 'core' with: #('TWM-GUI')
	]! !

!ConfigurationOfTilingWindowManager methodsFor: 'symbolic versions' stamp: 'LaurentLaffont 3/21/2013 20:53'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'pharo1.3.x' version: '1.3'.
	spec for: #'pharo1.4.x' version: '1.3'.
	spec for: #'pharo2.0.x' version: '2.0'.
	 
		
! !

!ConfigurationOfTilingWindowManager methodsFor: 'accessing' stamp: 'GuillermoPolito 6/12/2011 17:13'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfTilingWindowManager methodsFor: 'symbolic versions' stamp: 'LaurentLaffont 3/21/2013 20:53'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'pharo1.2.x' version: '1.0'.
	spec for: #'pharo1.3.x' version: '1.1'.
	spec for: #'pharo1.4.x' version: '1.3'.
	spec for: #'pharo2.0.x' version: '2.0'.
! !

!ConfigurationOfTilingWindowManager methodsFor: 'versions' stamp: 'GuillermoPolito 6/12/2011 17:16'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'GuillePolito'.
		spec description: 'Release 1.0 of this project '.
	].
	
	spec for: #pharo do: [		
		spec 
			project: 'Keymapping' with: '1.7';
			package: 'TWM' with: 'TWM-LaurentLaffont.57'.
	]
			! !

!ConfigurationOfTilingWindowManager methodsFor: 'versions' stamp: 'LaurentLaffont 7/5/2011 21:40'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #stable.
		spec author: 'Laurent Laffont'.
		spec description: '- add custom buttons using pragma <twmBarButton>
		                           - KeyMapping 1.9
		                           - various bug fixes
		                           - stable for 1.3'.
	].
	
	spec for: #pharo do: [		
		spec
			project: 'Keymapping' with: '1.9';
			package: 'TWM' with: 'TWM-BernardoContreras.68'.
	]
			! !

!ConfigurationOfTilingWindowManager methodsFor: 'versions' stamp: 'LaurentLaffont 7/5/2011 21:40'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Laurent Laffont'.
		spec description: '- start work for Pharo 1.4'.
	].
	
	spec for: #pharo do: [		
		spec
			project: 'Keymapping' with: '1.9';
			package: 'TWM'.
	]
			! !

!ConfigurationOfTilingWindowManager methodsFor: 'versions' stamp: 'LaurentLaffont 4/18/2012 21:54'!
version13: spec
	<version: '1.3' imports: #('1.3-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Laurent Laffont'.
		spec description: 'split TWM into several packages to handle dependencies'.
	].
	
	spec for: #pharo do: [		
		spec
			project: 'Keymapping' with: '2.2';
			package: 'TWM-Core' with: 'TWM-Core-LaurentLaffont.4';
			package: 'TWM-GUI' with: 'TWM-GUI-LaurentLaffont.7';
			package: 'TWM-Tests' with: 'TWM-Tests-LaurentLaffont.3';
			package: 'TWM-KeyMapping' with: 'TWM-KeyMapping-LaurentLaffont.3';
			package: 'TWM-Theme' with: 'TWM-Theme-LaurentLaffont.4'
	]
			! !

!ConfigurationOfTilingWindowManager methodsFor: 'versions' stamp: 'LaurentLaffont 3/21/2013 22:15'!
version20: spec
	<version: '2.0' imports: #('2.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Laurent Laffont'.
		spec description: 'Port to Pharo 2 and SmalltalkHub'.
	].
	
	spec for: #pharo do: [		
		spec
			package: 'TWM-Core' with: 'TWM-Core-LaurentLaffont.5';
			package: 'TWM-GUI' with: 'TWM-GUI-LaurentLaffont.8';
			package: 'TWM-Tests' with: 'TWM-Tests-LaurentLaffont.4';
			package: 'TWM-KeyMapping' with: 'TWM-KeyMapping-LaurentLaffont.3';
			package: 'TWM-Theme' with: 'TWM-Theme-LaurentLaffont.5'
	]
			! !
